@@ -148,7 +148,7 @@ class GitlabEpic:
 
         # update result
         result = issue_participants if issue_participants else list()
-        result = author_as_participant if result is None else result + author_as_participant
+        result = author_as_participant if result is None else result
         result = mentions_as_participants if result is None else (result + mentions_as_participants if mentions_as_participants else result)
 
         # dedup one last time post merge
