@@ -91,11 +91,14 @@ class GitlabIssue:
         if self.iid and self.connection.token and self.connection.version:
 
             # query api
-            result = self.connection.paginate(
+            r = self.connection.paginate(
                 endpoint="projects/%s/issues/%s/participants" % (
                     self.project_id,
                     self.iid
                 )
             )
 
+            # remove author as participant
+            result = [d for d in r if d["id"] != self.issue["author"]["id"]]
+
         return result
