@@ -6,19 +6,18 @@ class GitlabUser:
     GitlabUser is a GitLab User.
     """
 
-    def __init__(self, id: str = None, username: str = None, user: dict = None, token :str = configuration.GITLAB_TOKEN, version: str = configuration.GITLAB_API_VERSION):
+    def __init__(self, id: str = None, username: str = None, user: dict = None, connection: GitlabConnection = None, token :str = configuration.GITLAB_TOKEN, version: str = configuration.GITLAB_API_VERSION):
         """
         Args:
+            connection (GitlabConnection): glapi connection
             id (string): GitLab User id
             token (string): GitLab personal access or deploy token
             user (dict): key/values representing a Gitlab User
             version (string): GitLab API version as base url
         """
 
-        self.connection = GitlabConnection(
-            token=token,
-            version=version
-        )
+        self.connection = connection if connection else GitlabConnection(token=token, version=version)
+        self.gitlab_type = "user"
         self.id = id
 
         # check param
@@ -42,9 +41,9 @@ class GitlabUser:
                 self.user = user_data[0] if len(user_data) > 0 else dict()
                 self.id = self.user["id"] if self.user else None
 
-    def extract_events(self, actions: list, date_start: str = None, date_end: str = None) -> dict:
+    def extract_events(self, actions: list = None, date_start: str = None, date_end: str = None) -> dict:
         """
-        Extract user-specific event data.
+        Extract project-specific event data.
 
         Args:
             actions (list): enums where each represent an event action type https://docs.gitlab.com/ee/user/index.html#user-contribution-events
@@ -55,32 +54,41 @@ class GitlabUser:
             A dictionary where keys are event action types and corresponding values are lists of dictionaries where each represents a GitLab Event.
         """
 
-        result = None
+        result = list()
         params = dict()
 
-        # check params
-        if date_end: params["before"] = date_end
-        if date_start: params["after"] = date_start
-
         # check for connection ready
         if self.id and self.connection.token and self.connection.version:
 
-            # update result
-            result = dict()
+            # check params
+            if date_end: params["created_before"] = date_end
+            if date_start: params["created_after"] = date_start
 
-            # loop through actions
-            for action in actions:
+            # if actions are provided
+            if actions:
 
-                # update params
-                params["action"] = action
+                # loop through actions
+                for action in actions:
+
+                    # update for action
+                    params["action"] = action
+
+                    # get events
+                    result += self.connection.paginate(
+                        endpoint="users/%s/events" % self.id,
+                        params=params
+                    )
+
+            # no actions specified
+            else:
 
                 # get events
-                result[action] = self.connection.paginate(
+                result = self.connection.paginate(
                     endpoint="users/%s/events" % self.id,
                     params=params
                 )
 
-        return result
+        return result if result else None
 
     def extract_issues(self, scope: str, date_start: str = None, date_end: str = None) -> list:
         """
